# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/viewunite/v1/viewunite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/viewunite/v1/viewunite.proto\x12\x19\x62ilibili.app.viewunite.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a\x19google/protobuf/any.proto\"G\n\rAttentionCard\x12\x36\n\tshow_time\x18\x01 \x03(\x0b\x32#.bilibili.app.viewunite.v1.ShowTime\"\xb5\x01\n\tBadgeType\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"(\n\x13\x42izFollowVideoParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"\x1f\n\x10\x42izJumpLinkParam\x12\x0b\n\x03url\x18\x01 \x01(\t\"k\n\x17\x42izReserveActivityParam\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12\x12\n\nreserve_id\x18\x05 \x01(\x03\"&\n\x13\x42izReserveGameParam\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\"2\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\"U\n\x0c\x43hronosParam\x12\x16\n\x0e\x65ngine_version\x18\x01 \x01(\t\x12\x18\n\x10message_protocol\x18\x02 \x01(\t\x12\x13\n\x0bservice_key\x18\x03 \x01(\t\"\xa2\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\x0e\n\x06id_str\x18\n \x01(\t\"\xe5\x02\n\x0c\x43ontractCard\x12\x18\n\x10\x64isplay_progress\x18\x01 \x01(\x02\x12\x18\n\x10\x64isplay_accuracy\x18\x02 \x01(\x03\x12\x18\n\x10\x64isplay_duration\x18\x03 \x01(\x03\x12\x11\n\tshow_mode\x18\x04 \x01(\x05\x12\x11\n\tpage_type\x18\x05 \x01(\x05\x12\x34\n\x05upper\x18\x06 \x01(\x0b\x32%.bilibili.app.viewunite.v1.UpperInfos\x12\x19\n\x11is_follow_display\x18\x07 \x01(\x05\x12\x35\n\x04text\x18\x08 \x01(\x0b\x32\'.bilibili.app.viewunite.v1.ContractText\x12#\n\x1b\x66ollow_display_end_duration\x18\t \x01(\x03\x12\x17\n\x0fis_play_display\x18\n \x01(\x05\x12\x1b\n\x13is_interact_display\x18\x0b \x01(\x05\"E\n\x0c\x43ontractText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x14\n\x0cinline_title\x18\x03 \x01(\t\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"\xbd\x01\n\nDmResource\x12\x39\n\x0b\x63ommand_dms\x18\x01 \x03(\x0b\x32$.bilibili.app.viewunite.v1.CommandDm\x12;\n\tattention\x18\x02 \x01(\x0b\x32(.bilibili.app.viewunite.v1.AttentionCard\x12\x37\n\x05\x63\x61rds\x18\x03 \x03(\x0b\x32(.bilibili.app.viewunite.v1.OperationCard\"\x92\x02\n\x08Material\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.bilibili.app.viewunite.v1.MaterialBizType\x12\r\n\x05param\x18\x05 \x01(\t\x12\x13\n\x0bstatic_icon\x18\x06 \x01(\t\x12\x10\n\x08\x62g_color\x18\x07 \x01(\t\x12\x0e\n\x06\x62g_pic\x18\x08 \x01(\t\x12\x11\n\tjump_type\x18\t \x01(\x05\x12\x36\n\tpage_type\x18\n \x01(\x0e\x32#.bilibili.app.viewunite.v1.PageType\x12\x12\n\nneed_login\x18\x0b \x01(\x08\"\xbb\x03\n\rOperationCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\x08\x12\x34\n\x08\x62iz_type\x18\x05 \x01(\x0e\x32\".bilibili.app.viewunite.v1.BizType\x12@\n\x07\x63ontent\x18\x06 \x01(\x0b\x32/.bilibili.app.viewunite.v1.OperationCardContent\x12>\n\x06\x66ollow\x18\x07 \x01(\x0b\x32..bilibili.app.viewunite.v1.BizFollowVideoParam\x12\x43\n\x07reserve\x18\x08 \x01(\x0b\x32\x32.bilibili.app.viewunite.v1.BizReserveActivityParam\x12\x39\n\x04jump\x18\t \x01(\x0b\x32+.bilibili.app.viewunite.v1.BizJumpLinkParam\x12<\n\x04game\x18\n \x01(\x0b\x32..bilibili.app.viewunite.v1.BizReserveGameParam\"\x91\x01\n\x14OperationCardContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x04 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x05 \x01(\t\x12\x15\n\rshow_selected\x18\x06 \x01(\x08\"\\\n\x0cPlayStrategy\x12\x12\n\nstrategies\x18\x01 \x03(\t\x12\x1f\n\x17recommend_show_strategy\x18\x02 \x01(\x05\x12\x17\n\x0f\x61uto_play_toast\x18\x03 \x01(\t\"`\n\rPointMaterial\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x42\n\x0fmaterial_source\x18\x02 \x01(\x0e\x32).bilibili.app.viewunite.v1.MaterialSource\"\xca\x01\n\tSelection\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x04item\x18\x02 \x03(\x0b\x32(.bilibili.app.viewunite.v1.SelectionItem\x12\x34\n\x08\x61rc_type\x18\x03 \x01(\x0e\x32\".bilibili.app.viewunite.v1.ArcType\x12@\n\x0eselection_type\x18\x04 \x01(\x0e\x32(.bilibili.app.viewunite.v1.SelectionType\"\xbf\x01\n\rSelectionItem\x12\x0b\n\x03\x61id\x18\x01 \x01(\x04\x12\x0b\n\x03\x63id\x18\x02 \x01(\x04\x12\x38\n\nbadge_type\x18\x04 \x01(\x0b\x32$.bilibili.app.viewunite.v1.BadgeType\x12\r\n\x05title\x18\x05 \x01(\t\x12\x12\n\nlong_title\x18\x06 \x01(\t\x12\x37\n\tdimension\x18\x07 \x01(\x0b\x32$.bilibili.app.viewunite.v1.Dimension\"\xca\x01\n\x0fSelectionModule\x12\x37\n\tselection\x18\x01 \x03(\x0b\x32$.bilibili.app.viewunite.v1.Selection\x12>\n\rserial_season\x18\x02 \x03(\x0b\x32\'.bilibili.app.viewunite.v1.SerialSeason\x12>\n\rplay_strategy\x18\x03 \x01(\x0b\x32\'.bilibili.app.viewunite.v1.PlayStrategy\"7\n\x0cSerialSeason\x12\x11\n\tseason_id\x18\x01 \x01(\r\x12\x14\n\x0cseason_title\x18\x02 \x01(\t\"N\n\x08ShowTime\x12\x12\n\nstart_time\x18\x01 \x01(\x05\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x05\x12\r\n\x05pos_x\x18\x03 \x01(\x01\x12\r\n\x05pos_y\x18\x04 \x01(\x01\"t\n\nUpperInfos\x12\x12\n\nfans_count\x18\x01 \x01(\x04\x12 \n\x18\x61rc_count_last_half_year\x18\x02 \x01(\x04\x12\x16\n\x0e\x66irst_up_dates\x18\x03 \x01(\x03\x12\x18\n\x10total_play_count\x18\x04 \x01(\x04\"\xc3\x01\n\nVideoGuide\x12\x35\n\x08material\x18\x01 \x03(\x0b\x32#.bilibili.app.viewunite.v1.Material\x12>\n\x0bvideo_point\x18\x02 \x01(\x0b\x32).bilibili.app.viewunite.v1.VideoViewPoint\x12>\n\rcontract_card\x18\x03 \x01(\x0b\x32\'.bilibili.app.viewunite.v1.ContractCard\"f\n\nVideoPoint\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x03\x12\n\n\x02to\x18\x03 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x06 \x01(\t\"y\n\tVideoShot\x12\x0f\n\x07pv_data\x18\x01 \x01(\t\x12\x11\n\timg_x_len\x18\x02 \x01(\x05\x12\x12\n\nimd_x_size\x18\x03 \x01(\x05\x12\x11\n\timg_y_len\x18\x04 \x01(\x05\x12\x12\n\nimg_y_size\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x03(\t\"\xa2\x01\n\x0eVideoViewPoint\x12\x35\n\x06points\x18\x01 \x03(\x0b\x32%.bilibili.app.viewunite.v1.VideoPoint\x12@\n\x0epoint_material\x18\x02 \x01(\x0b\x32(.bilibili.app.viewunite.v1.PointMaterial\x12\x17\n\x0fpoint_permanent\x18\x03 \x01(\x08\"|\n\x08ViewBase\x12\x38\n\nunion_type\x18\x01 \x01(\x0e\x32$.bilibili.app.viewunite.v1.UnionType\x12\x36\n\tpage_type\x18\x02 \x01(\x0e\x32#.bilibili.app.viewunite.v1.PageType\"\xaf\x01\n\x0fViewProgressReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x04\x12\x0b\n\x03\x63id\x18\x02 \x01(\x04\x12\x0e\n\x06up_mid\x18\x03 \x01(\x04\x12>\n\rchronos_param\x18\x04 \x01(\x0b\x32\'.bilibili.app.viewunite.v1.ChronosParam\x12\x32\n\x04type\x18\x05 \x01(\x0e\x32$.bilibili.app.viewunite.v1.UnionType\"\xef\x01\n\x11ViewProgressReply\x12:\n\x0bvideo_guide\x18\x01 \x01(\x0b\x32%.bilibili.app.viewunite.v1.VideoGuide\x12\x33\n\x07\x63hronos\x18\x02 \x01(\x0b\x32\".bilibili.app.viewunite.v1.Chronos\x12\x36\n\x08\x61rc_shot\x18\x03 \x01(\x0b\x32$.bilibili.app.viewunite.v1.VideoShot\x12\x31\n\x02\x64m\x18\x04 \x01(\x0b\x32%.bilibili.app.viewunite.v1.DmResource\"\xc2\x02\n\x07ViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x04\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x12\n\nsession_id\x18\x06 \x01(\t\x12\x43\n\x0bplayer_args\x18\x07 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08track_id\x18\x08 \x01(\t\x12K\n\rextra_content\x18\t \x03(\x0b\x32\x34.bilibili.app.viewunite.v1.ViewReq.ExtraContentEntry\x1a\x33\n\x11\x45xtraContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x01\n\tViewReply\x12\x36\n\tview_base\x18\x01 \x01(\x0b\x32#.bilibili.app.viewunite.v1.ViewBase\x12\x44\n\x10selection_module\x18\x03 \x01(\x0b\x32*.bilibili.app.viewunite.v1.SelectionModule\x12(\n\nsupplement\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any*^\n\x07\x41rcType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05PAGES\x10\x01\x12\n\n\x06SERIES\x10\x02\x12\x0c\n\x08POSITIVE\x10\x03\x12\x0b\n\x07SECTION\x10\x04\x12\n\n\x06RELATE\x10\x05\x12\x08\n\x04PUGV\x10\x06*\x91\x01\n\x07\x42izType\x12\x0f\n\x0b\x42izTypeNone\x10\x00\x12\x16\n\x12\x42izTypeFollowVideo\x10\x01\x12\x1a\n\x16\x42izTypeReserveActivity\x10\x02\x12\x13\n\x0f\x42izTypeJumpLink\x10\x03\x12\x14\n\x10\x42izTypeFavSeason\x10\x04\x12\x16\n\x12\x42izTypeReserveGame\x10\x05*\x82\x01\n\x0fMaterialBizType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x41\x43TIVITY\x10\x01\x12\x07\n\x03\x42GM\x10\x02\x12\n\n\x06\x45\x46\x46\x45\x43T\x10\x03\x12\x0e\n\nSHOOT_SAME\x10\x04\x12\x12\n\x0eSHOOT_TOGETHER\x10\x05\x12\x11\n\rACTIVITY_ICON\x10\x06\x12\x0b\n\x07NEW_BGM\x10\x07*)\n\x0eMaterialSource\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06\x42IJIAN\x10\x01*2\n\x0cPageCategory\x12\x0f\n\x0b\x43OMMON_PAGE\x10\x00\x12\x11\n\rACTIVITY_PAGE\x10\x01*\x1a\n\x08PageType\x12\x06\n\x02H5\x10\x00\x12\x06\n\x02NA\x10\x01*.\n\rSelectionType\x12\r\n\tLONGTITLE\x10\x00\x12\x0e\n\nSHORTTITLE\x10\x01*\x1d\n\tUnionType\x12\x07\n\x03UGC\x10\x00\x12\x07\n\x03OGV\x10\x01\x32\xc2\x01\n\x04View\x12P\n\x04View\x12\".bilibili.app.viewunite.v1.ViewReq\x1a$.bilibili.app.viewunite.v1.ViewReply\x12h\n\x0cViewProgress\x12*.bilibili.app.viewunite.v1.ViewProgressReq\x1a,.bilibili.app.viewunite.v1.ViewProgressReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.viewunite.v1.viewunite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VIEWREQ_EXTRACONTENTENTRY._options = None
  _VIEWREQ_EXTRACONTENTENTRY._serialized_options = b'8\001'
  _globals['_ARCTYPE']._serialized_start=5182
  _globals['_ARCTYPE']._serialized_end=5276
  _globals['_BIZTYPE']._serialized_start=5279
  _globals['_BIZTYPE']._serialized_end=5424
  _globals['_MATERIALBIZTYPE']._serialized_start=5427
  _globals['_MATERIALBIZTYPE']._serialized_end=5557
  _globals['_MATERIALSOURCE']._serialized_start=5559
  _globals['_MATERIALSOURCE']._serialized_end=5600
  _globals['_PAGECATEGORY']._serialized_start=5602
  _globals['_PAGECATEGORY']._serialized_end=5652
  _globals['_PAGETYPE']._serialized_start=5654
  _globals['_PAGETYPE']._serialized_end=5680
  _globals['_SELECTIONTYPE']._serialized_start=5682
  _globals['_SELECTIONTYPE']._serialized_end=5728
  _globals['_UNIONTYPE']._serialized_start=5730
  _globals['_UNIONTYPE']._serialized_end=5759
  _globals['_ATTENTIONCARD']._serialized_start=149
  _globals['_ATTENTIONCARD']._serialized_end=220
  _globals['_BADGETYPE']._serialized_start=223
  _globals['_BADGETYPE']._serialized_end=404
  _globals['_BIZFOLLOWVIDEOPARAM']._serialized_start=406
  _globals['_BIZFOLLOWVIDEOPARAM']._serialized_end=446
  _globals['_BIZJUMPLINKPARAM']._serialized_start=448
  _globals['_BIZJUMPLINKPARAM']._serialized_end=479
  _globals['_BIZRESERVEACTIVITYPARAM']._serialized_start=481
  _globals['_BIZRESERVEACTIVITYPARAM']._serialized_end=588
  _globals['_BIZRESERVEGAMEPARAM']._serialized_start=590
  _globals['_BIZRESERVEGAMEPARAM']._serialized_end=628
  _globals['_CHRONOS']._serialized_start=630
  _globals['_CHRONOS']._serialized_end=680
  _globals['_CHRONOSPARAM']._serialized_start=682
  _globals['_CHRONOSPARAM']._serialized_end=767
  _globals['_COMMANDDM']._serialized_start=770
  _globals['_COMMANDDM']._serialized_end=932
  _globals['_CONTRACTCARD']._serialized_start=935
  _globals['_CONTRACTCARD']._serialized_end=1292
  _globals['_CONTRACTTEXT']._serialized_start=1294
  _globals['_CONTRACTTEXT']._serialized_end=1363
  _globals['_DIMENSION']._serialized_start=1365
  _globals['_DIMENSION']._serialized_end=1423
  _globals['_DMRESOURCE']._serialized_start=1426
  _globals['_DMRESOURCE']._serialized_end=1615
  _globals['_MATERIAL']._serialized_start=1618
  _globals['_MATERIAL']._serialized_end=1892
  _globals['_OPERATIONCARD']._serialized_start=1895
  _globals['_OPERATIONCARD']._serialized_end=2338
  _globals['_OPERATIONCARDCONTENT']._serialized_start=2341
  _globals['_OPERATIONCARDCONTENT']._serialized_end=2486
  _globals['_PLAYSTRATEGY']._serialized_start=2488
  _globals['_PLAYSTRATEGY']._serialized_end=2580
  _globals['_POINTMATERIAL']._serialized_start=2582
  _globals['_POINTMATERIAL']._serialized_end=2678
  _globals['_SELECTION']._serialized_start=2681
  _globals['_SELECTION']._serialized_end=2883
  _globals['_SELECTIONITEM']._serialized_start=2886
  _globals['_SELECTIONITEM']._serialized_end=3077
  _globals['_SELECTIONMODULE']._serialized_start=3080
  _globals['_SELECTIONMODULE']._serialized_end=3282
  _globals['_SERIALSEASON']._serialized_start=3284
  _globals['_SERIALSEASON']._serialized_end=3339
  _globals['_SHOWTIME']._serialized_start=3341
  _globals['_SHOWTIME']._serialized_end=3419
  _globals['_UPPERINFOS']._serialized_start=3421
  _globals['_UPPERINFOS']._serialized_end=3537
  _globals['_VIDEOGUIDE']._serialized_start=3540
  _globals['_VIDEOGUIDE']._serialized_end=3735
  _globals['_VIDEOPOINT']._serialized_start=3737
  _globals['_VIDEOPOINT']._serialized_end=3839
  _globals['_VIDEOSHOT']._serialized_start=3841
  _globals['_VIDEOSHOT']._serialized_end=3962
  _globals['_VIDEOVIEWPOINT']._serialized_start=3965
  _globals['_VIDEOVIEWPOINT']._serialized_end=4127
  _globals['_VIEWBASE']._serialized_start=4129
  _globals['_VIEWBASE']._serialized_end=4253
  _globals['_VIEWPROGRESSREQ']._serialized_start=4256
  _globals['_VIEWPROGRESSREQ']._serialized_end=4431
  _globals['_VIEWPROGRESSREPLY']._serialized_start=4434
  _globals['_VIEWPROGRESSREPLY']._serialized_end=4673
  _globals['_VIEWREQ']._serialized_start=4676
  _globals['_VIEWREQ']._serialized_end=4998
  _globals['_VIEWREQ_EXTRACONTENTENTRY']._serialized_start=4947
  _globals['_VIEWREQ_EXTRACONTENTENTRY']._serialized_end=4998
  _globals['_VIEWREPLY']._serialized_start=5001
  _globals['_VIEWREPLY']._serialized_end=5180
  _globals['_VIEW']._serialized_start=5762
  _globals['_VIEW']._serialized_end=5956
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HelloWorldReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___HelloWorldReq = HelloWorldReq

@typing_extensions.final
class HelloWorldResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.str
    """"""
    def __init__(
        self,
        *,
        data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___HelloWorldResp = HelloWorldResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ViewPgcAny(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    season_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        season_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id", "season_type", b"season_type"]) -> None: ...

global___ViewPgcAny = ViewPgcAny



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _WHRatio:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WHRatioEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WHRatio.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    W_H_RATIO_1_1: _WHRatio.ValueType  # 0
    W_H_RATIO_16_9: _WHRatio.ValueType  # 1
    W_H_RATIO_3_4: _WHRatio.ValueType  # 2
    W_H_RATIO_CUSTOM: _WHRatio.ValueType  # 3

class WHRatio(_WHRatio, metaclass=_WHRatioEnumTypeWrapper):
    """"""

W_H_RATIO_1_1: WHRatio.ValueType  # 0
W_H_RATIO_16_9: WHRatio.ValueType  # 1
W_H_RATIO_3_4: WHRatio.ValueType  # 2
W_H_RATIO_CUSTOM: WHRatio.ValueType  # 3
global___WHRatio = WHRatio

@typing_extensions.final
class ItemWHRatio(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RATIO_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ratio: builtins.int
    """"""
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    def __init__(
        self,
        *,
        ratio: builtins.int = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "ratio", b"ratio", "width", b"width"]) -> None: ...

global___ItemWHRatio = ItemWHRatio



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/other.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/app/distribution/setting/other.proto\x12\'bilibili.app.distribution.setting.other\x1a/bilibili/app/distribution/v1/distribution.proto\"\xdb\x04\n\x13OtherSettingsConfig\x12@\n\x0ewatermark_type\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12H\n\x16web_image_quality_type\x18\x02 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12G\n\x16\x65nable_read_pasteboard\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12@\n\x0fpaste_auto_jump\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12K\n\x1amini_screen_play_when_back\x18\x05 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x46\n\x15\x65nable_resume_playing\x18\x06 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12H\n\x17\x65nable_wifi_auto_update\x18\x07 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12N\n\x1d\x65nable_guide_screenshot_share\x18\x08 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.other_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OTHERSETTINGSCONFIG']._serialized_start=140
  _globals['_OTHERSETTINGSCONFIG']._serialized_end=743
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ArcType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ArcTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ArcType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ArcType.ValueType  # 0
    """"""
    PAGES: _ArcType.ValueType  # 1
    """"""
    SERIES: _ArcType.ValueType  # 2
    """"""
    POSITIVE: _ArcType.ValueType  # 3
    """"""
    SECTION: _ArcType.ValueType  # 4
    """"""
    RELATE: _ArcType.ValueType  # 5
    """"""
    PUGV: _ArcType.ValueType  # 6
    """"""

class ArcType(_ArcType, metaclass=_ArcTypeEnumTypeWrapper):
    """ 业务类型"""

UNKNOWN: ArcType.ValueType  # 0
""""""
PAGES: ArcType.ValueType  # 1
""""""
SERIES: ArcType.ValueType  # 2
""""""
POSITIVE: ArcType.ValueType  # 3
""""""
SECTION: ArcType.ValueType  # 4
""""""
RELATE: ArcType.ValueType  # 5
""""""
PUGV: ArcType.ValueType  # 6
""""""
global___ArcType = ArcType

class _BizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BizTypeNone: _BizType.ValueType  # 0
    """"""
    BizTypeFollowVideo: _BizType.ValueType  # 1
    """"""
    BizTypeReserveActivity: _BizType.ValueType  # 2
    """"""
    BizTypeJumpLink: _BizType.ValueType  # 3
    """"""
    BizTypeFavSeason: _BizType.ValueType  # 4
    """"""
    BizTypeReserveGame: _BizType.ValueType  # 5
    """"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """"""

BizTypeNone: BizType.ValueType  # 0
""""""
BizTypeFollowVideo: BizType.ValueType  # 1
""""""
BizTypeReserveActivity: BizType.ValueType  # 2
""""""
BizTypeJumpLink: BizType.ValueType  # 3
""""""
BizTypeFavSeason: BizType.ValueType  # 4
""""""
BizTypeReserveGame: BizType.ValueType  # 5
""""""
global___BizType = BizType

class _MaterialBizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaterialBizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialBizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NONE: _MaterialBizType.ValueType  # 0
    """"""
    ACTIVITY: _MaterialBizType.ValueType  # 1
    """"""
    BGM: _MaterialBizType.ValueType  # 2
    """"""
    EFFECT: _MaterialBizType.ValueType  # 3
    """"""
    SHOOT_SAME: _MaterialBizType.ValueType  # 4
    """"""
    SHOOT_TOGETHER: _MaterialBizType.ValueType  # 5
    """"""
    ACTIVITY_ICON: _MaterialBizType.ValueType  # 6
    """"""
    NEW_BGM: _MaterialBizType.ValueType  # 7
    """"""

class MaterialBizType(_MaterialBizType, metaclass=_MaterialBizTypeEnumTypeWrapper):
    """素材类型"""

NONE: MaterialBizType.ValueType  # 0
""""""
ACTIVITY: MaterialBizType.ValueType  # 1
""""""
BGM: MaterialBizType.ValueType  # 2
""""""
EFFECT: MaterialBizType.ValueType  # 3
""""""
SHOOT_SAME: MaterialBizType.ValueType  # 4
""""""
SHOOT_TOGETHER: MaterialBizType.ValueType  # 5
""""""
ACTIVITY_ICON: MaterialBizType.ValueType  # 6
""""""
NEW_BGM: MaterialBizType.ValueType  # 7
""""""
global___MaterialBizType = MaterialBizType

class _MaterialSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaterialSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _MaterialSource.ValueType  # 0
    """"""
    BIJIAN: _MaterialSource.ValueType  # 1
    """必剪素材"""

class MaterialSource(_MaterialSource, metaclass=_MaterialSourceEnumTypeWrapper):
    """素材来源"""

DEFAULT: MaterialSource.ValueType  # 0
""""""
BIJIAN: MaterialSource.ValueType  # 1
"""必剪素材"""
global___MaterialSource = MaterialSource

class _PageCategory:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PageCategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PageCategory.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMMON_PAGE: _PageCategory.ValueType  # 0
    """"""
    ACTIVITY_PAGE: _PageCategory.ValueType  # 1
    """"""

class PageCategory(_PageCategory, metaclass=_PageCategoryEnumTypeWrapper):
    """"""

COMMON_PAGE: PageCategory.ValueType  # 0
""""""
ACTIVITY_PAGE: PageCategory.ValueType  # 1
""""""
global___PageCategory = PageCategory

class _PageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    H5: _PageType.ValueType  # 0
    """H5页面(Webview)"""
    NA: _PageType.ValueType  # 1
    """原生页面(native)"""

class PageType(_PageType, metaclass=_PageTypeEnumTypeWrapper):
    """页面类型"""

H5: PageType.ValueType  # 0
"""H5页面(Webview)"""
NA: PageType.ValueType  # 1
"""原生页面(native)"""
global___PageType = PageType

class _SelectionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SelectionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SelectionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LONGTITLE: _SelectionType.ValueType  # 0
    """"""
    SHORTTITLE: _SelectionType.ValueType  # 1
    """"""

class SelectionType(_SelectionType, metaclass=_SelectionTypeEnumTypeWrapper):
    """"""

LONGTITLE: SelectionType.ValueType  # 0
""""""
SHORTTITLE: SelectionType.ValueType  # 1
""""""
global___SelectionType = SelectionType

class _UnionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UGC: _UnionType.ValueType  # 0
    """"""
    OGV: _UnionType.ValueType  # 1
    """"""

class UnionType(_UnionType, metaclass=_UnionTypeEnumTypeWrapper):
    """"""

UGC: UnionType.ValueType  # 0
""""""
OGV: UnionType.ValueType  # 1
""""""
global___UnionType = UnionType

@typing_extensions.final
class AttentionCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TIME_FIELD_NUMBER: builtins.int
    @property
    def show_time(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShowTime]:
        """"""
    def __init__(
        self,
        *,
        show_time: collections.abc.Iterable[global___ShowTime] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_time", b"show_time"]) -> None: ...

global___AttentionCard = AttentionCard

@typing_extensions.final
class BadgeType(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    border_color: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___BadgeType = BadgeType

@typing_extensions.final
class BizFollowVideoParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___BizFollowVideoParam = BizFollowVideoParam

@typing_extensions.final
class BizJumpLinkParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___BizJumpLinkParam = BizJumpLinkParam

@typing_extensions.final
class BizReserveActivityParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""
    type: builtins.str
    """"""
    oid: builtins.int
    """"""
    reserve_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        type: builtins.str = ...,
        oid: builtins.int = ...,
        reserve_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "from", b"from", "oid", b"oid", "reserve_id", b"reserve_id", "type", b"type"]) -> None: ...

global___BizReserveActivityParam = BizReserveActivityParam

@typing_extensions.final
class BizReserveGameParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAME_ID_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        game_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_id", b"game_id"]) -> None: ...

global___BizReserveGameParam = BizReserveGameParam

@typing_extensions.final
class Chronos(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    md5: builtins.str
    """"""
    file: builtins.str
    """"""
    sign: builtins.str
    """"""
    def __init__(
        self,
        *,
        md5: builtins.str = ...,
        file: builtins.str = ...,
        sign: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "md5", b"md5", "sign", b"sign"]) -> None: ...

global___Chronos = Chronos

@typing_extensions.final
class ChronosParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    engine_version: builtins.str
    """"""
    message_protocol: builtins.str
    """"""
    service_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        engine_version: builtins.str = ...,
        message_protocol: builtins.str = ...,
        service_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["engine_version", b"engine_version", "message_protocol", b"message_protocol", "service_key", b"service_key"]) -> None: ...

global___ChronosParam = ChronosParam

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    oid: builtins.int
    """"""
    mid: builtins.int
    """"""
    command: builtins.str
    """"""
    content: builtins.str
    """"""
    progress: builtins.int
    """"""
    ctime: builtins.str
    """"""
    mtime: builtins.str
    """"""
    extra: builtins.str
    """"""
    id_str: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        id_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "id_str", b"id_str", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress"]) -> None: ...

global___CommandDm = CommandDm

@typing_extensions.final
class ContractCard(google.protobuf.message.Message):
    """视频播放时弹出的卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_PROGRESS_FIELD_NUMBER: builtins.int
    DISPLAY_ACCURACY_FIELD_NUMBER: builtins.int
    DISPLAY_DURATION_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    IS_FOLLOW_DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLLOW_DISPLAY_END_DURATION_FIELD_NUMBER: builtins.int
    IS_PLAY_DISPLAY_FIELD_NUMBER: builtins.int
    IS_INTERACT_DISPLAY_FIELD_NUMBER: builtins.int
    display_progress: builtins.float
    """在第几秒弹出"""
    display_accuracy: builtins.int
    """"""
    display_duration: builtins.int
    """弹出后停留的时间"""
    show_mode: builtins.int
    """展示方式, 暂未知对应关系"""
    page_type: builtins.int
    """页面类型, 暂未知对应关系"""
    @property
    def upper(self) -> global___UpperInfos:
        """"""
    is_follow_display: builtins.int
    """"""
    @property
    def text(self) -> global___ContractText:
        """卡片的文字说明信息"""
    follow_display_end_duration: builtins.int
    """"""
    is_play_display: builtins.int
    """"""
    is_interact_display: builtins.int
    """"""
    def __init__(
        self,
        *,
        display_progress: builtins.float = ...,
        display_accuracy: builtins.int = ...,
        display_duration: builtins.int = ...,
        show_mode: builtins.int = ...,
        page_type: builtins.int = ...,
        upper: global___UpperInfos | None = ...,
        is_follow_display: builtins.int = ...,
        text: global___ContractText | None = ...,
        follow_display_end_duration: builtins.int = ...,
        is_play_display: builtins.int = ...,
        is_interact_display: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text", "upper", b"upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_accuracy", b"display_accuracy", "display_duration", b"display_duration", "display_progress", b"display_progress", "follow_display_end_duration", b"follow_display_end_duration", "is_follow_display", b"is_follow_display", "is_interact_display", b"is_interact_display", "is_play_display", b"is_play_display", "page_type", b"page_type", "show_mode", b"show_mode", "text", b"text", "upper", b"upper"]) -> None: ...

global___ContractCard = ContractCard

@typing_extensions.final
class ContractText(google.protobuf.message.Message):
    """视频播放时弹出的卡片的文字说明信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    INLINE_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    inline_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        inline_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_title", b"inline_title", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___ContractText = ContractText

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    rotate: builtins.int
    """"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class DmResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_DMS_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    CARDS_FIELD_NUMBER: builtins.int
    @property
    def command_dms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """"""
    @property
    def attention(self) -> global___AttentionCard:
        """"""
    @property
    def cards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCard]:
        """"""
    def __init__(
        self,
        *,
        command_dms: collections.abc.Iterable[global___CommandDm] | None = ...,
        attention: global___AttentionCard | None = ...,
        cards: collections.abc.Iterable[global___OperationCard] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attention", b"attention"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "cards", b"cards", "command_dms", b"command_dms"]) -> None: ...

global___DmResource = DmResource

@typing_extensions.final
class Material(google.protobuf.message.Message):
    """素材详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    STATIC_ICON_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_PIC_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    type: global___MaterialBizType.ValueType
    """"""
    param: builtins.str
    """"""
    static_icon: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_pic: builtins.str
    """"""
    jump_type: builtins.int
    """"""
    page_type: global___PageType.ValueType
    """"""
    need_login: builtins.bool
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        url: builtins.str = ...,
        type: global___MaterialBizType.ValueType = ...,
        param: builtins.str = ...,
        static_icon: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_pic: builtins.str = ...,
        jump_type: builtins.int = ...,
        page_type: global___PageType.ValueType = ...,
        need_login: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_pic", b"bg_pic", "icon", b"icon", "jump_type", b"jump_type", "need_login", b"need_login", "page_type", b"page_type", "param", b"param", "static_icon", b"static_icon", "text", b"text", "type", b"type", "url", b"url"]) -> None: ...

global___Material = Material

@typing_extensions.final
class OperationCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    FOLLOW_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    JUMP_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    to: builtins.int
    """"""
    status: builtins.bool
    """"""
    biz_type: global___BizType.ValueType
    """"""
    @property
    def content(self) -> global___OperationCardContent:
        """"""
    @property
    def follow(self) -> global___BizFollowVideoParam:
        """"""
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """"""
    @property
    def jump(self) -> global___BizJumpLinkParam:
        """"""
    @property
    def game(self) -> global___BizReserveGameParam:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        to: builtins.int = ...,
        status: builtins.bool = ...,
        biz_type: global___BizType.ValueType = ...,
        content: global___OperationCardContent | None = ...,
        follow: global___BizFollowVideoParam | None = ...,
        reserve: global___BizReserveActivityParam | None = ...,
        jump: global___BizJumpLinkParam | None = ...,
        game: global___BizReserveGameParam | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "follow", b"follow", "game", b"game", "jump", b"jump", "reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "content", b"content", "follow", b"follow", "from", b"from", "game", b"game", "id", b"id", "jump", b"jump", "reserve", b"reserve", "status", b"status", "to", b"to"]) -> None: ...

global___OperationCard = OperationCard

@typing_extensions.final
class OperationCardContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SHOW_SELECTED_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    icon: builtins.str
    """"""
    button_title: builtins.str
    """"""
    button_selected_title: builtins.str
    """"""
    show_selected: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        icon: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        show_selected: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "icon", b"icon", "show_selected", b"show_selected", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___OperationCardContent = OperationCardContent

@typing_extensions.final
class PlayStrategy(google.protobuf.message.Message):
    """播放策略"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRATEGIES_FIELD_NUMBER: builtins.int
    RECOMMEND_SHOW_STRATEGY_FIELD_NUMBER: builtins.int
    AUTO_PLAY_TOAST_FIELD_NUMBER: builtins.int
    @property
    def strategies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    recommend_show_strategy: builtins.int
    """"""
    auto_play_toast: builtins.str
    """自动播放时的提示语"""
    def __init__(
        self,
        *,
        strategies: collections.abc.Iterable[builtins.str] | None = ...,
        recommend_show_strategy: builtins.int = ...,
        auto_play_toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_play_toast", b"auto_play_toast", "recommend_show_strategy", b"recommend_show_strategy", "strategies", b"strategies"]) -> None: ...

global___PlayStrategy = PlayStrategy

@typing_extensions.final
class PointMaterial(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    MATERIAL_SOURCE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    material_source: global___MaterialSource.ValueType
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        material_source: global___MaterialSource.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_source", b"material_source", "url", b"url"]) -> None: ...

global___PointMaterial = PointMaterial

@typing_extensions.final
class Selection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    ARC_TYPE_FIELD_NUMBER: builtins.int
    SELECTION_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SelectionItem]:
        """"""
    arc_type: global___ArcType.ValueType
    """"""
    selection_type: global___SelectionType.ValueType
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        item: collections.abc.Iterable[global___SelectionItem] | None = ...,
        arc_type: global___ArcType.ValueType = ...,
        selection_type: global___SelectionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_type", b"arc_type", "item", b"item", "selection_type", b"selection_type", "title", b"title"]) -> None: ...

global___Selection = Selection

@typing_extensions.final
class SelectionItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    BADGE_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LONG_TITLE_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    @property
    def badge_type(self) -> global___BadgeType:
        """"""
    title: builtins.str
    """"""
    long_title: builtins.str
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        badge_type: global___BadgeType | None = ...,
        title: builtins.str = ...,
        long_title: builtins.str = ...,
        dimension: global___Dimension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_type", b"badge_type", "dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "badge_type", b"badge_type", "cid", b"cid", "dimension", b"dimension", "long_title", b"long_title", "title", b"title"]) -> None: ...

global___SelectionItem = SelectionItem

@typing_extensions.final
class SelectionModule(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTION_FIELD_NUMBER: builtins.int
    SERIAL_SEASON_FIELD_NUMBER: builtins.int
    PLAY_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def selection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Selection]:
        """"""
    @property
    def serial_season(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SerialSeason]:
        """"""
    @property
    def play_strategy(self) -> global___PlayStrategy:
        """"""
    def __init__(
        self,
        *,
        selection: collections.abc.Iterable[global___Selection] | None = ...,
        serial_season: collections.abc.Iterable[global___SerialSeason] | None = ...,
        play_strategy: global___PlayStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_strategy", b"play_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_strategy", b"play_strategy", "selection", b"selection", "serial_season", b"serial_season"]) -> None: ...

global___SelectionModule = SelectionModule

@typing_extensions.final
class SerialSeason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TITLE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    season_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        season_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id", "season_title", b"season_title"]) -> None: ...

global___SerialSeason = SerialSeason

@typing_extensions.final
class ShowTime(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    POS_X_FIELD_NUMBER: builtins.int
    POS_Y_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    pos_x: builtins.float
    """"""
    pos_y: builtins.float
    """"""
    def __init__(
        self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        pos_x: builtins.float = ...,
        pos_y: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "pos_x", b"pos_x", "pos_y", b"pos_y", "start_time", b"start_time"]) -> None: ...

global___ShowTime = ShowTime

@typing_extensions.final
class UpperInfos(google.protobuf.message.Message):
    """UP主信息(可是Upper这个... 程序员英文不过关吧? )"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FANS_COUNT_FIELD_NUMBER: builtins.int
    ARC_COUNT_LAST_HALF_YEAR_FIELD_NUMBER: builtins.int
    FIRST_UP_DATES_FIELD_NUMBER: builtins.int
    TOTAL_PLAY_COUNT_FIELD_NUMBER: builtins.int
    fans_count: builtins.int
    """粉丝数"""
    arc_count_last_half_year: builtins.int
    """过去半年内的稿件数"""
    first_up_dates: builtins.int
    """"""
    total_play_count: builtins.int
    """UP稿件总播放数"""
    def __init__(
        self,
        *,
        fans_count: builtins.int = ...,
        arc_count_last_half_year: builtins.int = ...,
        first_up_dates: builtins.int = ...,
        total_play_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count_last_half_year", b"arc_count_last_half_year", "fans_count", b"fans_count", "first_up_dates", b"first_up_dates", "total_play_count", b"total_play_count"]) -> None: ...

global___UpperInfos = UpperInfos

@typing_extensions.final
class VideoGuide(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIAL_FIELD_NUMBER: builtins.int
    VIDEO_POINT_FIELD_NUMBER: builtins.int
    CONTRACT_CARD_FIELD_NUMBER: builtins.int
    @property
    def material(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Material]:
        """"""
    @property
    def video_point(self) -> global___VideoViewPoint:
        """"""
    @property
    def contract_card(self) -> global___ContractCard:
        """"""
    def __init__(
        self,
        *,
        material: collections.abc.Iterable[global___Material] | None = ...,
        video_point: global___VideoViewPoint | None = ...,
        contract_card: global___ContractCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card", "video_point", b"video_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card", "material", b"material", "video_point", b"video_point"]) -> None: ...

global___VideoGuide = VideoGuide

@typing_extensions.final
class VideoPoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LOGO_URL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    to: builtins.int
    """"""
    content: builtins.str
    """"""
    cover: builtins.str
    """"""
    logo_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        to: builtins.int = ...,
        content: builtins.str = ...,
        cover: builtins.str = ...,
        logo_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "cover", b"cover", "from", b"from", "logo_url", b"logo_url", "to", b"to", "type", b"type"]) -> None: ...

global___VideoPoint = VideoPoint

@typing_extensions.final
class VideoShot(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PV_DATA_FIELD_NUMBER: builtins.int
    IMG_X_LEN_FIELD_NUMBER: builtins.int
    IMD_X_SIZE_FIELD_NUMBER: builtins.int
    IMG_Y_LEN_FIELD_NUMBER: builtins.int
    IMG_Y_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    pv_data: builtins.str
    """"""
    img_x_len: builtins.int
    """"""
    imd_x_size: builtins.int
    """"""
    img_y_len: builtins.int
    """"""
    img_y_size: builtins.int
    """"""
    @property
    def image(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        pv_data: builtins.str = ...,
        img_x_len: builtins.int = ...,
        imd_x_size: builtins.int = ...,
        img_y_len: builtins.int = ...,
        img_y_size: builtins.int = ...,
        image: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "imd_x_size", b"imd_x_size", "img_x_len", b"img_x_len", "img_y_len", b"img_y_len", "img_y_size", b"img_y_size", "pv_data", b"pv_data"]) -> None: ...

global___VideoShot = VideoShot

@typing_extensions.final
class VideoViewPoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POINTS_FIELD_NUMBER: builtins.int
    POINT_MATERIAL_FIELD_NUMBER: builtins.int
    POINT_PERMANENT_FIELD_NUMBER: builtins.int
    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoPoint]:
        """"""
    @property
    def point_material(self) -> global___PointMaterial:
        """"""
    point_permanent: builtins.bool
    """"""
    def __init__(
        self,
        *,
        points: collections.abc.Iterable[global___VideoPoint] | None = ...,
        point_material: global___PointMaterial | None = ...,
        point_permanent: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["point_material", b"point_material"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["point_material", b"point_material", "point_permanent", b"point_permanent", "points", b"points"]) -> None: ...

global___VideoViewPoint = VideoViewPoint

@typing_extensions.final
class ViewBase(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNION_TYPE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    union_type: global___UnionType.ValueType
    """"""
    page_type: global___PageType.ValueType
    """"""
    def __init__(
        self,
        *,
        union_type: global___UnionType.ValueType = ...,
        page_type: global___PageType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_type", b"page_type", "union_type", b"union_type"]) -> None: ...

global___ViewBase = ViewBase

@typing_extensions.final
class ViewProgressReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    CHRONOS_PARAM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    @property
    def chronos_param(self) -> global___ChronosParam:
        """"""
    type: global___UnionType.ValueType
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        up_mid: builtins.int = ...,
        chronos_param: global___ChronosParam | None = ...,
        type: global___UnionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chronos_param", b"chronos_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "chronos_param", b"chronos_param", "cid", b"cid", "type", b"type", "up_mid", b"up_mid"]) -> None: ...

global___ViewProgressReq = ViewProgressReq

@typing_extensions.final
class ViewProgressReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_GUIDE_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    ARC_SHOT_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    @property
    def video_guide(self) -> global___VideoGuide:
        """"""
    @property
    def chronos(self) -> global___Chronos:
        """"""
    @property
    def arc_shot(self) -> global___VideoShot:
        """"""
    @property
    def dm(self) -> global___DmResource:
        """"""
    def __init__(
        self,
        *,
        video_guide: global___VideoGuide | None = ...,
        chronos: global___Chronos | None = ...,
        arc_shot: global___VideoShot | None = ...,
        dm: global___DmResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "chronos", b"chronos", "dm", b"dm", "video_guide", b"video_guide"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "chronos", b"chronos", "dm", b"dm", "video_guide", b"video_guide"]) -> None: ...

global___ViewProgressReply = ViewProgressReply

@typing_extensions.final
class ViewReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    EXTRA_CONTENT_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    session_id: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    track_id: builtins.str
    """"""
    @property
    def extra_content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        session_id: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        track_id: builtins.str = ...,
        extra_content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "extra_content", b"extra_content", "from", b"from", "from_spmid", b"from_spmid", "player_args", b"player_args", "session_id", b"session_id", "spmid", b"spmid", "track_id", b"track_id"]) -> None: ...

global___ViewReq = ViewReq

@typing_extensions.final
class ViewReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_BASE_FIELD_NUMBER: builtins.int
    SELECTION_MODULE_FIELD_NUMBER: builtins.int
    SUPPLEMENT_FIELD_NUMBER: builtins.int
    @property
    def view_base(self) -> global___ViewBase:
        """"""
    @property
    def selection_module(self) -> global___SelectionModule:
        """"""
    @property
    def supplement(self) -> google.protobuf.any_pb2.Any:
        """使用 pgcanymodel / ugcanymodel 进行proto any转换成对应业务码结构体"""
    def __init__(
        self,
        *,
        view_base: global___ViewBase | None = ...,
        selection_module: global___SelectionModule | None = ...,
        supplement: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["selection_module", b"selection_module", "supplement", b"supplement", "view_base", b"view_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["selection_module", b"selection_module", "supplement", b"supplement", "view_base", b"view_base"]) -> None: ...

global___ViewReply = ViewReply



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MessagePullsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    HAS_NEXT_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """"""
    pn: builtins.int
    """"""
    ps: builtins.int
    """"""
    count: builtins.int
    """"""
    has_next: builtins.bool
    """"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        count: builtins.int = ...,
        has_next: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "data", b"data", "has_next", b"has_next", "pn", b"pn", "ps", b"ps"]) -> None: ...

global___MessagePullsReply = MessagePullsReply

@typing_extensions.final
class MessagePullsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_SEQ_ID_FIELD_NUMBER: builtins.int
    END_SEQ_ID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    start_seq_id: builtins.int
    """"""
    end_seq_id: builtins.int
    """"""
    pn: builtins.int
    """"""
    ps: builtins.int
    """"""
    def __init__(
        self,
        *,
        start_seq_id: builtins.int = ...,
        end_seq_id: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_seq_id", b"end_seq_id", "pn", b"pn", "ps", b"ps", "start_seq_id", b"start_seq_id"]) -> None: ...

global___MessagePullsReq = MessagePullsReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Pause: _PlayStatus.ValueType  # 0
    """暂停"""
    Play: _PlayStatus.ValueType  # 1
    """播放"""
    End: _PlayStatus.ValueType  # 2
    """终止"""

class PlayStatus(_PlayStatus, metaclass=_PlayStatusEnumTypeWrapper):
    """播放状态"""

Pause: PlayStatus.ValueType  # 0
"""暂停"""
Play: PlayStatus.ValueType  # 1
"""播放"""
End: PlayStatus.ValueType  # 2
"""终止"""
global___PlayStatus = PlayStatus

class _RoomType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoomTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RoomType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Private: _RoomType.ValueType  # 0
    """私密"""
    Open: _RoomType.ValueType  # 1
    """公开"""

class RoomType(_RoomType, metaclass=_RoomTypeEnumTypeWrapper):
    """房间类型"""

Private: RoomType.ValueType  # 0
"""私密"""
Open: RoomType.ValueType  # 1
"""公开"""
global___RoomType = RoomType

class _MessageDomain:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MessageDomainEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageDomain.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultDomain: _MessageDomain.ValueType  # 0
    """默认"""
    RoomMid: _MessageDomain.ValueType  # 1
    """房间用户"""
    SystemInfo: _MessageDomain.ValueType  # 2
    """系统通知"""

class MessageDomain(_MessageDomain, metaclass=_MessageDomainEnumTypeWrapper):
    """信息通知发送领域"""

DefaultDomain: MessageDomain.ValueType  # 0
"""默认"""
RoomMid: MessageDomain.ValueType  # 1
"""房间用户"""
SystemInfo: MessageDomain.ValueType  # 2
"""系统通知"""
global___MessageDomain = MessageDomain

class _MessageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultType: _MessageType.ValueType  # 0
    """默认"""
    ChatMessage: _MessageType.ValueType  # 1
    """房间用户"""
    SystemMessage: _MessageType.ValueType  # 2
    """系统通知"""

class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
    """通知信息类型"""

DefaultType: MessageType.ValueType  # 0
"""默认"""
ChatMessage: MessageType.ValueType  # 1
"""房间用户"""
SystemMessage: MessageType.ValueType  # 2
"""系统通知"""
global___MessageType = MessageType

class _TriggerType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultTrigger: _TriggerType.ValueType  # 0
    """默认"""
    Relation: _TriggerType.ValueType  # 1
    """关注、取消关注"""

class TriggerType(_TriggerType, metaclass=_TriggerTypeEnumTypeWrapper):
    """触发通知类型"""

DefaultTrigger: TriggerType.ValueType  # 0
"""默认"""
Relation: TriggerType.ValueType  # 1
"""关注、取消关注"""
global___TriggerType = TriggerType

@typing_extensions.final
class RoomMemberChangeEvent(google.protobuf.message.Message):
    """房间人员变更事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    OWNER_ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    owner_id: builtins.int
    """房主id"""
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfoProto]:
        """房间成员列表"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        owner_id: builtins.int = ...,
        members: collections.abc.Iterable[global___UserInfoProto] | None = ...,
        message: global___MessageProto | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["members", b"members", "message", b"message", "owner_id", b"owner_id", "room_id", b"room_id"]) -> None: ...

global___RoomMemberChangeEvent = RoomMemberChangeEvent

@typing_extensions.final
class ProgressSyncEvent(google.protobuf.message.Message):
    """播放进度同步事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    EPISODE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    season_id: builtins.int
    """播放中的season_id"""
    episode_id: builtins.int
    """播放中的episode_id"""
    status: global___PlayStatus.ValueType
    """播放状态"""
    progress: builtins.int
    """房主播放进度"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        season_id: builtins.int = ...,
        episode_id: builtins.int = ...,
        status: global___PlayStatus.ValueType = ...,
        progress: builtins.int = ...,
        message: global___MessageProto | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["episode_id", b"episode_id", "message", b"message", "progress", b"progress", "room_id", b"room_id", "season_id", b"season_id", "status", b"status"]) -> None: ...

global___ProgressSyncEvent = ProgressSyncEvent

@typing_extensions.final
class RoomUpdateEvent(google.protobuf.message.Message):
    """房间状态更新"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    type: global___RoomType.ValueType
    """房间变更状态"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        type: global___RoomType.ValueType = ...,
        message: global___MessageProto | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "room_id", b"room_id", "type", b"type"]) -> None: ...

global___RoomUpdateEvent = RoomUpdateEvent

@typing_extensions.final
class RoomDestroyEvent(google.protobuf.message.Message):
    """房间销毁通知"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        message: global___MessageProto | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "room_id", b"room_id"]) -> None: ...

global___RoomDestroyEvent = RoomDestroyEvent

@typing_extensions.final
class RoomTriggerEvent(google.protobuf.message.Message):
    """房间触发通知"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """操作人"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    trigger: global___TriggerType.ValueType
    """触发类型"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        message: global___MessageProto | None = ...,
        trigger: global___TriggerType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "mid", b"mid", "trigger", b"trigger"]) -> None: ...

global___RoomTriggerEvent = RoomTriggerEvent

@typing_extensions.final
class UserInfoProto(google.protobuf.message.Message):
    """用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NICKNAME_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户id"""
    face: builtins.str
    """用户头像url"""
    nickname: builtins.str
    """昵称"""
    level: builtins.int
    """等级"""
    sign: builtins.str
    """签名"""
    @property
    def vip(self) -> global___VipProto:
        """大会员信息"""
    @property
    def official(self) -> global___OfficialProto:
        """身份认证信息"""
    @property
    def pendant(self) -> global___PendantProto:
        """挂件信息"""
    buvid: builtins.str
    """设备buvid"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        face: builtins.str = ...,
        nickname: builtins.str = ...,
        level: builtins.int = ...,
        sign: builtins.str = ...,
        vip: global___VipProto | None = ...,
        official: global___OfficialProto | None = ...,
        pendant: global___PendantProto | None = ...,
        buvid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official", b"official", "pendant", b"pendant", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid", b"buvid", "face", b"face", "level", b"level", "mid", b"mid", "nickname", b"nickname", "official", b"official", "pendant", b"pendant", "sign", b"sign", "vip", b"vip"]) -> None: ...

global___UserInfoProto = UserInfoProto

@typing_extensions.final
class MessageProto(google.protobuf.message.Message):
    """通知信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    content: builtins.str
    """可带占位符匹配的消息体 ep "还没有其他小伙伴，[去邀请>]<https://big.bilibili.com/mobile/giftIndex?mid=123>" """
    content_type: builtins.int
    """消息体类型
    0:json格式的文本消息 1:支持全文本可点(破冰)
    """
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        content_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "content_type", b"content_type"]) -> None: ...

global___MessageProto = MessageProto

@typing_extensions.final
class VipProto(google.protobuf.message.Message):
    """大会员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    type: builtins.int
    status: builtins.int
    due_date: builtins.int
    vip_pay_type: builtins.int
    theme_type: builtins.int
    avatar_subscript: builtins.int
    """大会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """
    nickname_color: builtins.str
    """昵称色值，可能为空，色值示例：#FFFB9E60"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        vip_pay_type: builtins.int = ...,
        theme_type: builtins.int = ...,
        avatar_subscript: builtins.int = ...,
        nickname_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar_subscript", b"avatar_subscript", "due_date", b"due_date", "nickname_color", b"nickname_color", "status", b"status", "theme_type", b"theme_type", "type", b"type", "vip_pay_type", b"vip_pay_type"]) -> None: ...

global___VipProto = VipProto

@typing_extensions.final
class OfficialProto(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    role: builtins.int
    title: builtins.str
    desc: builtins.str
    type: builtins.int
    def __init__(
        self,
        *,
        role: builtins.int = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "role", b"role", "title", b"title", "type", b"type"]) -> None: ...

global___OfficialProto = OfficialProto

@typing_extensions.final
class PendantProto(google.protobuf.message.Message):
    """挂件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    IMAGE_ENHANCE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    name: builtins.str
    image: builtins.str
    expire: builtins.int
    image_enhance: builtins.str
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        expire: builtins.int = ...,
        image_enhance: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire", b"expire", "image", b"image", "image_enhance", b"image_enhance", "name", b"name", "pid", b"pid"]) -> None: ...

global___PendantProto = PendantProto

@typing_extensions.final
class MessageEvent(google.protobuf.message.Message):
    """通用信息通知"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    MSG_ID_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    MSG_ID2_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    msg_id: builtins.int
    """消息id"""
    ts: builtins.int
    """消息发送服务端时间 时间戳 单位秒"""
    oid: builtins.int
    """信息通知发送主体id"""
    domain: global___MessageDomain.ValueType
    """信息通知发送领域"""
    type: global___MessageType.ValueType
    """通知信息类型"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    @property
    def user(self) -> global___UserInfoProto:
        """消息发送用户信息"""
    msg_id2: builtins.str
    """消息id str类型"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        msg_id: builtins.int = ...,
        ts: builtins.int = ...,
        oid: builtins.int = ...,
        domain: global___MessageDomain.ValueType = ...,
        type: global___MessageType.ValueType = ...,
        message: global___MessageProto | None = ...,
        user: global___UserInfoProto | None = ...,
        msg_id2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain", "message", b"message", "msg_id", b"msg_id", "msg_id2", b"msg_id2", "oid", b"oid", "room_id", b"room_id", "ts", b"ts", "type", b"type", "user", b"user"]) -> None: ...

global___MessageEvent = MessageEvent

@typing_extensions.final
class RemoveChatEvent(google.protobuf.message.Message):
    """聊天信息清除通知"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    MSG_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    msg_id: builtins.int
    """撤回的聊天信息id"""
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        msg_id: builtins.int = ...,
        message: global___MessageProto | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "msg_id", b"msg_id", "room_id", b"room_id"]) -> None: ...

global___RemoveChatEvent = RemoveChatEvent

@typing_extensions.final
class FreyaEventBody(google.protobuf.message.Message):
    """"一起看"房间事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    WHITE_MID_FIELD_NUMBER: builtins.int
    IGNORE_MID_FIELD_NUMBER: builtins.int
    MEMBER_CHANGE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    ROOM_UPDATE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REMOVE_CHAT_FIELD_NUMBER: builtins.int
    ROOM_DESTROY_FIELD_NUMBER: builtins.int
    ROOM_TRIGGER_FIELD_NUMBER: builtins.int
    SEQUENCE_ID_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""
    @property
    def white_mid(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """接收事件消息的白名单用户"""
    @property
    def ignore_mid(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """不处理信息的黑名单用户 优先级低于白名单 当白名单有数据时 忽略黑名单"""
    @property
    def member_change(self) -> global___RoomMemberChangeEvent:
        """房间人员变更事件"""
    @property
    def progress(self) -> global___ProgressSyncEvent:
        """播放进度同步事件"""
    @property
    def room_update(self) -> global___RoomUpdateEvent:
        """房间状态更新"""
    @property
    def message(self) -> global___MessageEvent:
        """通用信息通知"""
    @property
    def remove_chat(self) -> global___RemoveChatEvent:
        """聊天信息清除通知"""
    @property
    def room_destroy(self) -> global___RoomDestroyEvent:
        """房间销毁通知"""
    @property
    def room_trigger(self) -> global___RoomTriggerEvent:
        """房间触发通知"""
    sequence_id: builtins.int
    """消息序列号"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        white_mid: collections.abc.Iterable[builtins.int] | None = ...,
        ignore_mid: collections.abc.Iterable[builtins.int] | None = ...,
        member_change: global___RoomMemberChangeEvent | None = ...,
        progress: global___ProgressSyncEvent | None = ...,
        room_update: global___RoomUpdateEvent | None = ...,
        message: global___MessageEvent | None = ...,
        remove_chat: global___RemoveChatEvent | None = ...,
        room_destroy: global___RoomDestroyEvent | None = ...,
        room_trigger: global___RoomTriggerEvent | None = ...,
        sequence_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event", "member_change", b"member_change", "message", b"message", "progress", b"progress", "remove_chat", b"remove_chat", "room_destroy", b"room_destroy", "room_trigger", b"room_trigger", "room_update", b"room_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "ignore_mid", b"ignore_mid", "member_change", b"member_change", "message", b"message", "progress", b"progress", "remove_chat", b"remove_chat", "room_destroy", b"room_destroy", "room_id", b"room_id", "room_trigger", b"room_trigger", "room_update", b"room_update", "sequence_id", b"sequence_id", "white_mid", b"white_mid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["member_change", "progress", "room_update", "message", "remove_chat", "room_destroy", "room_trigger"] | None: ...

global___FreyaEventBody = FreyaEventBody
